# geoshaha


[![image](https://img.shields.io/pypi/v/geoshaha.svg)](https://pypi.python.org/pypi/geoshaha)
[![image](https://img.shields.io/conda/vn/conda-forge/geoshaha.svg)](https://anaconda.org/conda-forge/geoshaha)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT license
-   Documentation: https://giswqs.github.io/geoshaha
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
